==> ws_event-1.0.0.tar.gz: ws_event/src/Plugin/Block/EventInfoBlock.php <==
<?php

namespace Drupal\ws_event\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use LinkedIn\Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Event Info block.
 *
 * @Block(
 *   id = "lb_event_info",
 *   admin_label = @Translation("Event Info Block"),
 *   category = @Translation("Event blocks")
 * )
 */
class EventInfoBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * Cuurent node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $node;


  /**
   * Logger channel for the Y-LB.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Constructs a new EventInfoBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $currentRouteMatch, LoggerChannelFactoryInterface $loggerFactory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $currentRouteMatch;
    $this->node = $currentRouteMatch->getParameter('node');
    $this->logger = $loggerFactory->get('y_lb');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->node || !$this->node->hasField('field_event_location')) {
      return [];
    }

    $location = $this->node->get('field_event_location')->entity;
    $dateTime = $this->getDateTime();
    $address = $this->getAddress($location);
    $directions = $this->getDirections($location);
    $locationLink = $this->getLocationLink($location);

    $build = [
      '#date' => $dateTime['date'],
      '#time' => $dateTime['time'],
      '#location_link' => $locationLink,
      '#location_address' => $address,
      '#location_directions' => $directions,
    ];
    return $build;
  }

  /**
   * Returns formatted Location address.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Component\Render\MarkupInterface|string
   */
  protected function getAddress($location) {
    $address = $location->get('field_location_address')->first();
    if ($address) {
      $address_array = $address->toArray();
      $location_address = "{$address_array['address_line1']}<br />{$address_array['locality']}<br /> {$address_array['administrative_area']} {$address_array['postal_code']}";
      return Markup::create($location_address);
    }
    return '';
  }

  /**
   * Returns render array for the Location Directions Link or empty string.
   *
   * @param \Drupal\node\NodeInterface $node
   *
   * @return array|mixed|string
   */
  protected function getDirections($node) {
    if (
      in_array($node->getType(), ['branch', 'camp', 'facility', 'location']) &&
      $node->hasField('field_location_directions')
    ) {
      $directions_title = t("Directions");
      if (!$node->field_location_directions->isEmpty()) {
        $directions_field_url = $node->field_location_directions->get(0);
        if ($directions_field_url && $directions_field_url->getUrl()->toString() !== "") {
          return $directions_field_url;
        }
        if ($directions_field_url->title) {
          $directions_title = $directions_field_url->title;
        }
      }

      $address = $node->field_location_address->get(0);
      if ($address) {
        $address_array = $address->toArray();
        $location_address = "{$address_array['address_line1']} {$address_array['locality']}, {$address_array['administrative_area']} {$address_array['postal_code']}";
        $directions_url = Url::fromUri('https://www.google.com/maps/dir/', [
          'query' => [
            'api' => 1,
            'destination' => $location_address,
          ],
        ]);

        $link = Link::fromTextAndUrl($directions_title, $directions_url);
        $link = $link->toRenderable();
        $link['#attributes'] = ['target' => ['_blank']];
        return $link;
      }
    }
    return '';
  }

  /**
   * Returns Location link.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Core\Link
   */
  protected function getLocationLink($location) {
    $url = $location->toUrl();
    return Link::fromTextAndUrl($location->label(), $url);
  }

  /**
   * Helper method to build Date/Time strings from node data.
   *
   * @return array
   */
  protected function getDateTime(){
    $result = [
      'date' => '',
      'time' => ''
    ];

    $formatDate = 'F j, Y';
    $formatTime = 'g:i a';

    try {
      $startDate = $this->node->field_event_dates->value;
      $endDate = $this->node->field_event_dates->end_value;

      $start = new \DateTimeImmutable($startDate);
      $end = new \DateTimeImmutable($endDate);

      $result['date'] = $start->format($formatDate);
      // Start and end time differs
      if ($end->diff($start)->h > 0) {
        $result['time'] = $start->format($formatTime) . ' - ' . $end->format($formatTime);
      }
      else {
        $result['time'] = $end->format($formatTime);
      }
    }
    catch (Exception $e) {
      $this->logger->debug($e->getMessage());
    }

    return $result;
  }

}

==> ws_event-1.0.4.tar.gz: ws_event/src/Plugin/Block/EventInfoBlock.php <==
<?php

namespace Drupal\ws_event\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Link;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Url;
use LinkedIn\Exception;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Event Info block.
 *
 * @Block(
 *   id = "lb_event_info",
 *   admin_label = @Translation("Event Info Block"),
 *   category = @Translation("Event blocks")
 * )
 */
class EventInfoBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRouteMatch;

  /**
   * Cuurent node.
   *
   * @var \Drupal\node\Entity\Node
   */
  protected $node;


  /**
   * Logger channel for the Y-LB.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * Constructs a new EventInfoBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Routing\RouteProviderInterface $route_provider
   *   The route provider.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CurrentRouteMatch $currentRouteMatch, LoggerChannelFactoryInterface $loggerFactory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentRouteMatch = $currentRouteMatch;
    $this->node = $currentRouteMatch->getParameter('node');
    $this->logger = $loggerFactory->get('y_lb');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->node || !$this->node->hasField('field_event_location')) {
      return [];
    }

    $location = $this->node->get('field_event_location')->entity;
    $dateTime = $this->getDateTime();
    if ($this->node->hasField('field_location_address') &&
      ($fieldAddress = $this->node->get('field_location_address')) &&
      !$fieldAddress->isEmpty()) {
      $address = $this->getAddress($location, $fieldAddress->first());
      $directions = $this->getDirections($this->node);
      $locationLink = '';
    } else {
      $address = $this->getAddress($location);
      $directions = $this->getDirections($location);
      $locationLink = $this->getLocationLink($location);
    }

    $build = [
      '#date' => $dateTime['date'],
      '#time' => $dateTime['time'],
      '#location_link' => $locationLink,
      '#location_address' => $address,
      '#location_directions' => $directions,
    ];
    return $build;
  }

  /**
   * Returns formatted Location address.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Component\Render\MarkupInterface|string
   */
  protected function getAddress($location, $address = NULL) {
    if(!$address) {
      $address = $location->get('field_location_address')->first();
    }
    if ($address) {
      $address_array = $address->toArray();
      $location_address = "{$address_array['address_line1']}<br />{$address_array['locality']}<br /> {$address_array['administrative_area']} {$address_array['postal_code']}";
      return Markup::create($location_address);
    }
    return '';
  }

  /**
   * Returns render array for the Location Directions Link or empty string.
   *
   * @param \Drupal\node\NodeInterface $node
   *
   * @return array|mixed|string
   */
  protected function getDirections($node) {
    if (
      in_array($node->getType(), ['branch', 'camp', 'facility', 'location', 'lb_event']) &&
      $node->hasField('field_location_directions')
    ) {
      $directions_title = t("Directions");
      if (!$node->field_location_directions->isEmpty()) {
        $directions_field_url = $node->field_location_directions->get(0);
        if ($directions_field_url && $directions_field_url->getUrl()->toString() !== "") {
          $title = $directions_field_url->get('title')->getValue() ?? $directions_title;
          return Link::fromTextAndUrl($title, $directions_field_url->getUrl());
        }
        if ($directions_field_url->title) {
          $directions_title = $directions_field_url->title;
        }
      }

      $address = $node->field_location_address->get(0);
      if ($address) {
        $address_array = $address->toArray();
        $location_address = "{$address_array['address_line1']} {$address_array['locality']}, {$address_array['administrative_area']} {$address_array['postal_code']}";
        $directions_url = Url::fromUri('https://www.google.com/maps/dir/', [
          'query' => [
            'api' => 1,
            'destination' => $location_address,
          ],
        ]);

        $link = Link::fromTextAndUrl($directions_title, $directions_url);
        $link = $link->toRenderable();
        $link['#attributes'] = ['target' => ['_blank']];
        return $link;
      }
    }
    return '';
  }

  /**
   * Returns Location link.
   *
   * @param \Drupal\node\NodeInterface $location
   *
   * @return \Drupal\Core\Link
   */
  protected function getLocationLink($location) {
    $url = $location->toUrl();
    return Link::fromTextAndUrl($location->label(), $url);
  }

  /**
   * Helper method to build Date/Time strings from node data.
   *
   * @return array
   */
  protected function getDateTime(){
    $result = [
      'date' => '',
      'time' => ''
    ];

    $formatDate = 'F j, Y';
    $formatTime = 'g:i a';

    try {
      $startDate = $this->node->field_event_dates->value;
      $endDate = $this->node->field_event_dates->end_value;

      $start = new \DateTimeImmutable($startDate);
      $end = new \DateTimeImmutable($endDate);

      $result['date'] = $start->format($formatDate);
      // Start and end time differs
      if ($end->diff($start)->h > 0) {
        $result['time'] = $start->format($formatTime) . ' - ' . $end->format($formatTime);
      }
      else {
        $result['time'] = $end->format($formatTime);
      }
    }
    catch (Exception $e) {
      $this->logger->debug($e->getMessage());
    }

    return $result;
  }

}
